@@ -36,6 +36,9 @@ class HFTransformersNLP(Component):
         "model_name": "bert",
         # Pre-Trained weights to be loaded(string)
         "model_weights": None,
+        # an optional path to a specific directory to download
+        # and cache the pre-trained model weights.
+        "cache_dir": None,
     }
 
     def __init__(self, component_config: Optional[Dict[Text, Any]] = None) -> None:
@@ -63,6 +66,7 @@ class HFTransformersNLP(Component):
             )
 
         self.model_weights = self.component_config["model_weights"]
+        self.cache_dir = self.component_config["cache_dir"]
 
         if not self.model_weights:
             logger.info(
@@ -74,10 +78,10 @@ class HFTransformersNLP(Component):
         logger.debug(f"Loading Tokenizer and Model for {self.model_name}")
 
         self.tokenizer = model_tokenizer_dict[self.model_name].from_pretrained(
-            self.model_weights
+            self.model_weights, cache_dir=self.cache_dir
         )
         self.model = model_class_dict[self.model_name].from_pretrained(
-            self.model_weights
+            self.model_weights, cache_dir=self.cache_dir
         )
 
         # Use a universal pad token since all transformer architectures do not have a
