@@ -445,6 +445,10 @@ class CRF(tf.keras.layers.Layer):
         self.num_tags = num_tags
         self.scale_loss = scale_loss
         self.transition_regularizer = tf.keras.regularizers.l2(reg_lambda)
+        self.f1_score_metric = tfa.metrics.F1Score(
+            num_classes=num_tags - 1,  # `0` prediction is not a prediction
+            average="micro",
+        )
 
     def build(self, input_shape: tf.TensorShape) -> None:
         # the weights should be created in `build` to apply random_seed
@@ -504,6 +508,25 @@ class CRF(tf.keras.layers.Layer):
 
         return tf.reduce_mean(loss)
 
+    def f1_score(
+        self, tag_ids: tf.Tensor, pred_ids: tf.Tensor, mask: tf.Tensor
+    ) -> tf.Tensor:
+        """Calculates f1 score for train predictions"""
+
+        mask_bool = tf.cast(mask[:, :, 0], tf.bool)
+
+        # pick only non padding values and flatten sequences
+        tag_ids_flat = tf.boolean_mask(tag_ids, mask_bool)
+        pred_ids_flat = tf.boolean_mask(pred_ids, mask_bool)
+
+        # set `0` prediction to not a prediction
+        num_tags = self.num_tags - 1
+
+        tag_ids_flat_one_hot = tf.one_hot(tag_ids_flat - 1, num_tags)
+        pred_ids_flat_one_hot = tf.one_hot(pred_ids_flat - 1, num_tags)
+
+        return self.f1_score_metric(tag_ids_flat_one_hot, pred_ids_flat_one_hot)
+
 
 class DotProductLoss(tf.keras.layers.Layer):
     """Dot-product loss layer.
